declare const ENTRY = 0;
declare const ARRAY_NODE = 1;
declare const INDEX_NODE = 2;
declare const COLLISION_NODE = 3;
export type Node<K, V> = ArrayNode<K, V> | CollisionNode<K, V> | IndexNode<K, V>;
export type Entry<K, V> = {
    k: K;
    type: typeof ENTRY;
    v: V;
};
export type ArrayNode<K, V> = {
    array: (Entry<K, V> | Node<K, V> | undefined)[];
    size: number;
    type: typeof ARRAY_NODE;
};
export type IndexNode<K, V> = {
    array: (Entry<K, V> | Node<K, V>)[];
    bitmap: number;
    type: typeof INDEX_NODE;
};
export type CollisionNode<K, V> = {
    array: Entry<K, V>[];
    hash: number;
    type: typeof COLLISION_NODE;
};
export type Flag = {
    val: boolean;
};
export type AssocFunction<T, K, V> = (root: T, shift: number, hash: number, key: K, val: V, addedLeaf: Flag) => Node<K, V>;
/**
 * An implementation of the native Map, but with deep-equality key comparison
 * API compatible with native Map, with exception of constructor
 * IN addition, a static Dict.from() function allows for additional conversions including objects and Maps
 */
export declare class Dict<K, V> implements Iterable<[K, V]> {
    /**
     * A function constructor that handles an EntriesArray, Object, or native Map
     */
    static from<K, V>(): Dict<K, V>;
    static from<V>(object: Record<string, V>): Dict<string, V>;
    static from<K, V>(map: Map<K, V>): Dict<string, V>;
    static from<K, V>(entries: Iterable<readonly [K, V]>): Dict<string, V>;
    static groupBy<K, V>(items: Iterable<V>, keySelector: (item: V, index: number) => K): Dict<K, V[]>;
    private root;
    private sizeInternal;
    constructor();
    constructor(iterable: Iterable<readonly [K, V]> | null);
    clear(): void;
    delete(key: K): boolean;
    entries(): IteratorObject<[K, V], undefined, unknown>;
    forEach(fn: (val: V, key: K) => void): void;
    get(key: K): V | undefined;
    has(key: K): boolean;
    keys(): IteratorObject<K, undefined, unknown>;
    set(key: K, val: V): Dict<K, V>;
    values(): IteratorObject<V, undefined, unknown>;
    get size(): number;
    hashCode(): number;
    [Symbol.iterator](): IteratorObject<[K, V], undefined, unknown>;
    equals(o: Dict<K, V>): boolean;
}
export {};
